@@ -20,7 +20,11 @@ class Doer(ABC):
 
         Here is some information about the environment: {uname}
 
-        You should respond with the following JSON object.
+        You should respond with a JSON object that has the keys "commands" and "explanation'.
+        "commands" is an array of strings representing shell commands. If the request would require multiple commands, respond with all the required commands in the array.
+        "explanation" is a string which at most one sentence, and cannot contain any other commands. The explanation should help the user understand what the commands are going to do.
+
+        Here is an example:
 
         {{
             "commands" : ["ls", "cat", ...],
@@ -28,10 +32,7 @@ class Doer(ABC):
         }}
 
         Do not respond with anything other than this JSON. Your response should be valid JSON. Do not include any notes.
-
-        The explanation must be at most one sentence, and cannot contain any other commands.
-        The explanation should help the user understand what the commands are going to do.
-        If the request would require multiple commands, respond with all the required commands in the array.
+        Do not rename the keys "commands" or "explanation".
     """
     )
 
