@@ -29,9 +29,16 @@ class GPT3Doer(Doer):
         contents = openai.Completion.create(
             engine=self.__class__.model,
             prompt=f"{self.prompt}\nRequest: {prompt}\n{{",
-            stop="}",
+            stop="}\n",
             temperature=0,
             max_tokens=256,
         )
         self.dprint(contents)
         return "{" + contents.choices[0]["text"] + "}"
+
+    def check_cache(self, key):
+        return self.state.get("cache", {}).get(f"{self.model}:{key}")
+
+    def update_cache(self, key, value):
+        cache = self.state["cache"] = self.state.get("cache", {})
+        cache[f"{self.model}:{key}"] = value
